==> owfs_2.8p15.orig.tar.gz: owfs-2.8p15/module/owserver/src/c/ping.c <==
/*
$Id: ping.c,v 1.3 2012/03/27 03:42:48 alfille Exp $
    OW_HTML -- OWFS used for the web
    OW -- One-Wire filesystem

    Written 2004 Paul H Alfille

 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

/* owserver -- responds to requests over a network socket, and processes them on the 1-wire bus/
         Basic idea: control the 1-wire bus and answer queries over a network socket
         Clients can be owperl, owfs, owhttpd, etc...
         Clients can be local or remote
                 Eventually will also allow bounce servers.

         syntax:
                 owserver
                 -u (usb)
                 -d /dev/ttyS1 (serial)
                 -p tcp port
                 e.g. 3001 or 10.183.180.101:3001 or /tmp/1wire
*/

#include "owserver.h"

#if OW_MT						// Handler for multithreaded approach -- with ping

/*
 * Routine for handling a single request
   returns 0 if ok, else non-zero for error
 */
struct client_msg ping_cm = {
	.version = 0 ,
	.payload = -1 ,
	.ret     = 0 ,
	.control_flags = 0 ,
	.size    = 0 ,
	.offset  = 0 ,
};

void PingClient(struct handlerdata *hd)
{
		ToClient(hd->file_descriptor, &ping_cm, NULL);	// send the ping
}

#endif							/* OW_MT */

==> owfs_3.1p1.orig.tar.gz: owfs-3.1p1/module/owserver/src/c/ping.c <==
/*
$Id$
    OW_HTML -- OWFS used for the web
    OW -- One-Wire filesystem

    Written 2004 Paul H Alfille

 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

/* owserver -- responds to requests over a network socket, and processes them on the 1-wire bus/
         Basic idea: control the 1-wire bus and answer queries over a network socket
         Clients can be owperl, owfs, owhttpd, etc...
         Clients can be local or remote
                 Eventually will also allow bounce servers.

         syntax:
                 owserver
                 -u (usb)
                 -d /dev/ttyS1 (serial)
                 -p tcp port
                 e.g. 3001 or 10.183.180.101:3001 or /tmp/1wire
*/

#include "owserver.h"

/*
 * Routine for handling a single request
   returns 0 if ok, else non-zero for error
 */
struct client_msg ping_cm = {
	.version = 0 ,
	.payload = -1 ,
	.ret     = 0 ,
	.control_flags = 0 ,
	.size    = 0 ,
	.offset  = 0 ,
};

void PingClient(struct handlerdata *hd)
{
		ToClient(hd->file_descriptor, &ping_cm, NULL);	// send the ping
}
